@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -20,30 +20,32 @@ using namespace KPIMTextEdit;
 
 TextReplaceWidget::TextReplaceWidget(QWidget *parent)
     : QWidget(parent)
+    , mReplace(new QLineEdit(this))
+    , mReplaceBtn(new QPushButton(i18n("Replace"), this))
+    , mReplaceAllBtn(new QPushButton(i18n("Replace All"), this))
 {
     auto lay = new QHBoxLayout(this);
-    QLabel *label = new QLabel(i18nc("Replace text", "Replace:"), this);
+    auto label = new QLabel(i18nc("Replace text", "Replace:"), this);
     lay->addWidget(label);
     const int marg1 = lay->contentsMargins().left();
     const int marg2 = lay->contentsMargins().right();
     lay->setContentsMargins(marg1, 0, marg2, 0);
 
-    mReplace = new QLineEdit(this);
     mReplace->setClearButtonEnabled(true);
     lay->addWidget(mReplace);
 
-    mReplaceBtn = new QPushButton(i18n("Replace"), this);
+    mReplace->setObjectName(QStringLiteral("mReplace"));
+    mReplaceBtn->setObjectName(QStringLiteral("mReplaceBtn"));
+    mReplaceAllBtn->setObjectName(QStringLiteral("mReplaceAllBtn"));
+
     connect(mReplaceBtn, &QPushButton::clicked, this, &TextReplaceWidget::replaceText);
     lay->addWidget(mReplaceBtn);
 
-    mReplaceAllBtn = new QPushButton(i18n("Replace All"), this);
     connect(mReplaceAllBtn, &QPushButton::clicked, this, &TextReplaceWidget::replaceAllText);
     lay->addWidget(mReplaceAllBtn);
 }
 
-TextReplaceWidget::~TextReplaceWidget()
-{
-}
+TextReplaceWidget::~TextReplaceWidget() = default;
 
 QLineEdit *TextReplaceWidget::replaceLineEdit() const
 {
@@ -58,33 +60,37 @@ void TextReplaceWidget::slotSearchStringEmpty(bool isEmpty)
 
 TextFindWidget::TextFindWidget(QWidget *parent)
     : QWidget(parent)
+    , mSearch(new QLineEdit(this))
+    , mFindPrevBtn(new QPushButton(QIcon::fromTheme(QStringLiteral("go-up-search")), i18nc("Find and go to the previous search match", "Previous"), this))
+    , mFindNextBtn(new QPushButton(QIcon::fromTheme(QStringLiteral("go-down-search")), i18nc("Find and go to the next search match", "Next"), this))
 {
     auto lay = new QHBoxLayout(this);
     const int marg1 = lay->contentsMargins().left();
     const int marg2 = lay->contentsMargins().right();
     lay->setContentsMargins(marg1, 0, marg2, 0);
-    QLabel *label = new QLabel(i18nc("Find text", "F&ind:"), this);
+    auto label = new QLabel(i18nc("Find text", "F&ind:"), this);
     lay->addWidget(label);
 
-    mSearch = new QLineEdit(this);
     mSearch->setToolTip(i18n("Text to search for"));
     mSearch->setClearButtonEnabled(true);
+    mSearch->setObjectName(QStringLiteral("mSearch"));
     label->setBuddy(mSearch);
     lay->addWidget(mSearch);
 
-    mFindNextBtn = new QPushButton(QIcon::fromTheme(QStringLiteral("go-down-search")), i18nc("Find and go to the next search match", "Next"), this);
     mFindNextBtn->setToolTip(i18n("Jump to next match"));
     lay->addWidget(mFindNextBtn);
     mFindNextBtn->setEnabled(false);
+    mFindNextBtn->setObjectName(QStringLiteral("mFindNextBtn"));
 
-    mFindPrevBtn = new QPushButton(QIcon::fromTheme(QStringLiteral("go-up-search")), i18nc("Find and go to the previous search match", "Previous"), this);
     mFindPrevBtn->setToolTip(i18n("Jump to previous match"));
     lay->addWidget(mFindPrevBtn);
     mFindPrevBtn->setEnabled(false);
+    mFindPrevBtn->setObjectName(QStringLiteral("mFindPrevBtn"));
 
     auto optionsBtn = new QPushButton(this);
     optionsBtn->setText(i18n("Options"));
     optionsBtn->setToolTip(i18n("Modify search behavior"));
+    optionsBtn->setObjectName(QStringLiteral("optionsBtn"));
     auto optionsMenu = new QMenu(optionsBtn);
     mCaseSensitiveAct = optionsMenu->addAction(i18n("Case sensitive"));
     mCaseSensitiveAct->setCheckable(true);
@@ -92,8 +98,12 @@ TextFindWidget::TextFindWidget(QWidget *parent)
     mWholeWordAct = optionsMenu->addAction(i18n("Whole word"));
     mWholeWordAct->setCheckable(true);
 
-    mRegExpAct = optionsMenu->addAction(i18n("Regular Expression"));
-    mRegExpAct->setCheckable(true);
+    mRegularExpressionAct = optionsMenu->addAction(i18n("Regular Expression"));
+    mRegularExpressionAct->setCheckable(true);
+
+    mRespectDiacriticAct = optionsMenu->addAction(i18n("Respect Diacritic and Accents"));
+    mRespectDiacriticAct->setCheckable(true);
+    mRespectDiacriticAct->setChecked(true);
 
     optionsBtn->setMenu(optionsMenu);
     lay->addWidget(optionsBtn);
@@ -102,13 +112,18 @@ TextFindWidget::TextFindWidget(QWidget *parent)
     connect(mFindPrevBtn, &QPushButton::clicked, this, &TextFindWidget::findPrev);
     connect(mCaseSensitiveAct, &QAction::toggled, this, &TextFindWidget::updateSearchOptions);
     connect(mWholeWordAct, &QAction::toggled, this, &TextFindWidget::updateSearchOptions);
-    connect(mRegExpAct, &QAction::toggled, this, &TextFindWidget::updateSearchOptions);
+    connect(mRespectDiacriticAct, &QAction::toggled, this, &TextFindWidget::updateSearchOptions);
+    connect(mRegularExpressionAct, &QAction::toggled, this, &TextFindWidget::slotRegularExpressionChanged);
     connect(mSearch, &QLineEdit::textChanged, this, &TextFindWidget::slotAutoSearch);
     connect(mSearch, &QLineEdit::returnPressed, this, &TextFindWidget::findNext);
 }
 
-TextFindWidget::~TextFindWidget()
+TextFindWidget::~TextFindWidget() = default;
+
+void TextFindWidget::slotRegularExpressionChanged(bool b)
 {
+    mRespectDiacriticAct->setEnabled(!b);
+    Q_EMIT updateSearchOptions();
 }
 
 void TextFindWidget::setFoundMatch(bool match)
@@ -153,7 +168,7 @@ QLineEdit *TextFindWidget::searchLineEdit() const
 
 bool TextFindWidget::isRegularExpression() const
 {
-    return mRegExpAct->isChecked();
+    return mRegularExpressionAct->isChecked();
 }
 
 QString TextFindWidget::searchText() const
@@ -161,7 +176,7 @@ QString TextFindWidget::searchText() const
     return mSearch->text();
 }
 
-QRegularExpression TextFindWidget::searchRegExp() const
+QRegularExpression TextFindWidget::searchRegularExpression() const
 {
     QRegularExpression reg;
     if (!mCaseSensitiveAct->isChecked()) {
@@ -175,14 +190,17 @@ QRegularExpression TextFindWidget::searchRegExp() const
     return reg;
 }
 
-QTextDocument::FindFlags TextFindWidget::searchOptions() const
+TextEditFindBarBase::FindFlags TextFindWidget::searchOptions() const
 {
-    QTextDocument::FindFlags opt = {};
+    TextEditFindBarBase::FindFlags opt = {};
     if (mCaseSensitiveAct->isChecked()) {
-        opt |= QTextDocument::FindCaseSensitively;
+        opt |= TextEditFindBarBase::FindCaseSensitively;
     }
     if (mWholeWordAct->isChecked()) {
-        opt |= QTextDocument::FindWholeWords;
+        opt |= TextEditFindBarBase::FindWholeWords;
+    }
+    if (mRespectDiacriticAct->isChecked()) {
+        opt |= TextEditFindBarBase::FindRespectDiacritics;
     }
     return opt;
 }
