@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -27,7 +27,12 @@ public:
 
     Q_REQUIRED_RESULT bool isReady() const;
 
-    enum State { Ready = 0, Speaking, Paused, BackendError };
+    enum State {
+        Ready = 0,
+        Speaking,
+        Paused,
+        BackendError,
+    };
 
     Q_REQUIRED_RESULT double volume() const;
     Q_REQUIRED_RESULT QVector<QLocale> availableLocales() const;
