@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -20,7 +20,10 @@
 using namespace KPIMTextEdit;
 TextToSpeechConfigWidget::TextToSpeechConfigWidget(QWidget *parent)
     : QWidget(parent)
+    , mLanguage(new KPIMTextEdit::TextToSpeechLanguageComboBox(this))
     , mAbstractTextToSpeechConfigInterface(new TextToSpeechConfigInterface(this))
+    , mAvailableEngine(new QComboBox(this))
+    , mVoice(new QComboBox(this))
 {
     auto layout = new QFormLayout(this);
     mVolume = new QSlider(this);
@@ -48,19 +51,16 @@ TextToSpeechConfigWidget::TextToSpeechConfigWidget(QWidget *parent)
     mPitch->setOrientation(Qt::Horizontal);
     layout->addRow(i18n("Pitch:"), mPitch);
 
-    mAvailableEngine = new QComboBox(this);
     mAvailableEngine->setObjectName(QStringLiteral("engine"));
     layout->addRow(i18n("Engine:"), mAvailableEngine);
     connect(mAvailableEngine, &QComboBox::currentIndexChanged, this, &TextToSpeechConfigWidget::slotEngineChanged);
     connect(mAvailableEngine, &QComboBox::currentIndexChanged, this, &TextToSpeechConfigWidget::valueChanged);
 
-    mLanguage = new KPIMTextEdit::TextToSpeechLanguageComboBox(this);
     mLanguage->setObjectName(QStringLiteral("language"));
     layout->addRow(i18n("Language:"), mLanguage);
     connect(mAvailableEngine, &QComboBox::currentIndexChanged, this, &TextToSpeechConfigWidget::slotLanguageChanged);
     connect(mLanguage, &QComboBox::currentIndexChanged, this, &TextToSpeechConfigWidget::valueChanged);
 
-    mVoice = new QComboBox(this);
     mVoice->setObjectName(QStringLiteral("voice"));
     layout->addRow(i18n("Voice:"), mVoice);
     connect(mVoice, &QComboBox::currentIndexChanged, this, &TextToSpeechConfigWidget::valueChanged);
@@ -68,9 +68,7 @@ TextToSpeechConfigWidget::TextToSpeechConfigWidget(QWidget *parent)
     QTimer::singleShot(0, this, &TextToSpeechConfigWidget::slotUpdateSettings);
 }
 
-TextToSpeechConfigWidget::~TextToSpeechConfigWidget()
-{
-}
+TextToSpeechConfigWidget::~TextToSpeechConfigWidget() = default;
 
 void TextToSpeechConfigWidget::valueChanged()
 {
